@@ -1,6 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Reports::Id;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Reports::Web::Controller::Tapper::Reports::Id::VERSION = '5.0.10';
+$Tapper::Reports::Web::Controller::Tapper::Reports::Id::VERSION = '5.0.11';
 use 5.010;
 use strict;
 use warnings;
@@ -125,6 +125,7 @@ sub index :Path :Args(1)
                 while (my $r = $rga_reports->next) {
                         if (my @report_failures = @{ $self->get_report_failures($r) }) {
                                 $c->stash->{failures}->{$r->id}{name} = $r->suite->name;
+                                $c->stash->{failures}->{$r->id}{machine_name} = $r->machine_name;
                                 push @{$c->stash->{failures}->{$r->id}{failures}}, @report_failures;
                         }
                 }
@@ -149,6 +150,7 @@ sub index :Path :Args(1)
                 while (my $r = $rgt_reports->next) {
                         if (my @report_failures = @{ $self->get_report_failures($r) }) {
                                 $c->stash->{failures}->{$r->id}{name} = $r->suite->name;
+                                $c->stash->{failures}->{$r->id}{machine_name} = $r->machine_name;
                                 push @{$c->stash->{failures}->{$r->id}{failures}}, @report_failures;
                         }
                 }
@@ -168,6 +170,7 @@ sub index :Path :Args(1)
 
         unless (my @report_failures = @{$c->stash->{failures}->{$c->stash->{report}->id}{failures} || []}) {
                 $c->stash->{failures}->{$c->stash->{report}->id}{name} = $c->stash->{report}->suite->name;
+                $c->stash->{failures}->{$c->stash->{report}->id}{machine_name} = $c->stash->{report}->machine_name;
                 push @{$c->stash->{failures}->{$c->stash->{report}->id}{failures}}, @report_failures;
         }
         %{$c->stash->{metareport}} = $self->generate_metareport_link($report_data);
